@@ -3,7 +3,7 @@ package Module::Install::CPANfile;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Module::CPANfile;
 use base qw(Module::Install::Base);
@@ -48,6 +48,10 @@ sub command_for {
         return 'recommends';
     }
 
+    if ($phase eq 'runtime') {
+        return 'requires';
+    }
+
     return "${phase}_requires";
 }
 
@@ -56,4 +60,4 @@ __END__
 
 =encoding utf-8
 
-#line 101
+#line 105
